@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 14's 2.6.35 kernel.
+# This is a kernel build script for Fedora 15's 2.6.41 kernel.
 #
 
 die () {
@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.35.14-97.fc14.src.rpm ]
+if [ ! -r kernel-2.6.41.1-1.fc15.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/14/SRPMS/kernel-2.6.35.14-97.fc14.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/15/SRPMS/kernel-2.6.41.1-1.fc15.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-2.6.35.14-97.fc14.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-2.6.35.14-97.fc14.src.rpm || die "Can't install source package."
+rpm --checksig kernel-2.6.41.1-1.fc15.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-2.6.41.1-1.fc15.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20111025.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20111118.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20111025.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20111025.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20111118.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20111118.tar.gz' || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
@@ -28,16 +28,16 @@ cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
 --- ccs-kernel.spec
 +++ ccs-kernel.spec
-@@ -23,7 +23,7 @@
+@@ -18,7 +18,7 @@
  #
  # (Uncomment the '#' and both spaces below to set the buildid.)
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.8.3p1
++%define buildid _tomoyo_1.8.3p3
  ###################################################################
  
  # The buildid can also be specified on the rpmbuild command line
-@@ -424,6 +424,11 @@
+@@ -388,6 +388,11 @@
  # to versions below the minimum
  #
  
@@ -49,7 +49,7 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -483,7 +488,7 @@
+@@ -447,7 +452,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -58,7 +58,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -988,7 +993,7 @@
+@@ -794,7 +799,7 @@
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
  Requires: perl\
@@ -67,18 +67,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1667,6 +1672,10 @@
+@@ -1240,6 +1245,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20111025.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.35-fedora-14.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20111118.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.41-fedora-15.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1695,6 +1704,9 @@
+@@ -1268,6 +1277,9 @@
  for i in *.config
  do
    mv $i .config
@@ -86,8 +86,8 @@ patch << "EOF" || die "Can't patch spec file."
 +  cat config.ccs >> .config
 +  sed -i -e 's:CONFIG_DEBUG_INFO=.*:# CONFIG_DEBUG_INFO is not set:' -- .config
    Arch=`head -1 .config | cut -b 3-`
-   make ARCH=$Arch %{oldconfig_target} > /dev/null
-   echo "# $Arch" > configs/$i
+   make ARCH=$Arch listnewconfig | grep -E '^CONFIG_' >.newoptions || true
+ %if %{listnewconfig_fail}
 EOF
 echo ""
 echo ""
@@ -97,7 +97,7 @@ echo "rpmbuild -bb /root/rpmbuild/SPECS/ccs-kernel.spec"
 echo "to build kernel rpm packages."
 echo ""
 ARCH=`uname -m`
-echo "I'll start 'rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
+echo "I'll start 'rpmbuild -bb --target $ARCH --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec' in 30 seconds. Press Ctrl-C to stop."
 sleep 30
-exec rpmbuild -bb --target $ARCH --with baseonly --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec
+exec rpmbuild -bb --target $ARCH --without debug --without debuginfo /root/rpmbuild/SPECS/ccs-kernel.spec
 exit 0
